@@ -33,6 +33,9 @@ THE SOFTWARE.
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <libxslt/xslt.h>
+#include <libxslt/xsltconfig.h>
+
 #include "xmlstar.h"
 
 extern int edMain(int argc, char **argv);
@@ -106,6 +109,56 @@ usage(int argc, char **argv, exit_status status)
     exit(status);
 }  
 
+/**
+ * Error reporting function
+ */
+void reportError(void *ptr, xmlErrorPtr error)
+{
+    ErrorInfo *errorInfo = (ErrorInfo*) ptr;
+
+    if (errorInfo && errorInfo->verbose)
+    {
+        int line = (!errorInfo->filename)? 0 :
+            (errorInfo->xmlReader)?
+            xmlTextReaderGetParserLineNumber(errorInfo->xmlReader) :
+            error->line;
+        if (line)
+        {
+            fprintf(stderr, "%s:%d: ", errorInfo->filename, line);
+        }
+    }
+
+    if (!errorInfo || errorInfo->verbose)
+    {
+        fprintf(stderr, "%s", error->message);
+    }
+}
+
+#define CHECK_MEM(ret) if (!ret) \
+        (fprintf(stderr, "out of memory\n"), exit(EXIT_INTERNAL_ERROR))
+
+void*
+xmalloc(size_t size)
+{
+    void *ret = malloc(size);
+    CHECK_MEM(ret);
+    return ret;
+}
+void*
+xrealloc(void *ptr, size_t size)
+{
+    void *ret = realloc(ptr, size);
+    CHECK_MEM(ret);
+    return ret;
+}
+char*
+xstrdup(const char *str)
+{
+    char *ret = (char*) xmlStrdup(BAD_CAST str);
+    CHECK_MEM(ret);
+    return ret;
+}
+
 /**
  *  This is the main function
  */
@@ -114,6 +167,9 @@ main(int argc, char **argv)
 {
     int ret = 0;
 
+    xmlMemSetup(free, xmalloc, xrealloc, xstrdup);
+    xmlSetStructuredErrorFunc(NULL, reportError);
+
     if (argc <= 1)
     {
         usage(argc, argv, EXIT_BAD_ARGS);
@@ -168,7 +224,12 @@ main(int argc, char **argv)
     }
     else if (!strcmp(argv[1], "--version"))
     {
-        fprintf(stdout, "%s\n", VERSION);
+        fprintf(stdout, "%s\n"
+            "compiled against libxml2 %s, linked with %s\n"
+            "compiled against libxslt %s, linked with %s\n",
+            VERSION,
+            LIBXML_DOTTED_VERSION, xmlParserVersion,
+            LIBXSLT_DOTTED_VERSION, xsltEngineVersion);
         ret = EXIT_SUCCESS;
     }
     else
