@@ -119,8 +119,8 @@ static const char edit_usage_str_1[] =
 
 static const char edit_usage_str_2[] =
 "<global-options> are:\n"
-"  -P (or --pf)        - preserve original formatting\n"
-"  -S (or --ps)        - preserve non-significant spaces\n"
+"  -P, or -S           - preserve whitespace nodes.\n"
+"     (or --pf, --ps)    Note that space between attributes is not preserved\n"
 "  -O (or --omit-decl) - omit XML declaration (<?xml ...?>)\n"
 "  -L (or --inplace)   - edit file inplace\n"
 "  -N <name>=<value>   - predefine namespaces (name without \'xmlns:\')\n"
@@ -257,7 +257,7 @@ edParseNSArr(const char** ns_arr, int* plen,
                 if (*plen >= MAX_NS_ARGS)
                 {
                     fprintf(stderr, "too many namespaces increase MAX_NS_ARGS\n");
-                    exit(2);
+                    exit(EXIT_BAD_ARGS);
                 }
 
                 ns_arr[*plen] = (char *)name;
@@ -552,19 +552,7 @@ edRename(xmlDocPtr doc, char *loc, char *val, XmlNodeType type)
                 */
                 for (i = 0; i < cur->nodeNr; i++)
                 {
-                    /*
-                     *  rename node
-                     */
-                    if (cur->nodeTab[i]->type == XML_ATTRIBUTE_NODE)
-                    {
-                        xmlFree((xmlChar *) cur->nodeTab[i]->name);
-                        cur->nodeTab[i]->name = xmlStrdup((const xmlChar*) val);
-                    }
-                    else
-                    {
-                        xmlFree((xmlChar *)cur->nodeTab[i]->name);
-                        cur->nodeTab[i]->name = xmlStrdup((const xmlChar*) val);
-                    }
+                    xmlNodeSetName(cur->nodeTab[i], BAD_CAST val);
                 }
             }
             break;
@@ -646,7 +634,7 @@ edDelete(xmlDocPtr doc, char *str)
                 {
                     if (cur->nodeTab[i]->type == XML_NAMESPACE_DECL) {
                         fprintf(stderr, "FIXME: can't delete namespace nodes\n");
-                        exit(2);
+                        exit(EXIT_INTERNAL_ERROR);
                     }
                     /*
                      *  delete node
@@ -871,7 +859,7 @@ edProcess(xmlDocPtr doc, XmlEdAction* ops, int ops_count)
 void
 edOutput(const char* filename, edOptions g_ops)
 {
-    xmlDocPtr doc = xmlParseFile(filename);
+    xmlDocPtr doc = xmlReadFile(filename, NULL, 0);
     int format = (g_ops.noblanks && !g_ops.preserveFormat);
 
     if (!doc)
@@ -879,7 +867,7 @@ edOutput(const char* filename, edOptions g_ops)
         edCleanupNSArr(ns_arr);
         xmlCleanupParser();
         xmlCleanupGlobals();
-        exit(2);
+        exit(EXIT_BAD_FILE);
     }
 
     edProcess(doc, ops, ops_count);
@@ -923,8 +911,6 @@ edMain(int argc, char **argv)
     static edOptions g_ops;
 
     if (argc < 3) edUsage(argv[0], EXIT_BAD_ARGS);
-    if (!strcmp(argv[2], "--help") || !strcmp(argv[2], "-h"))
-        edUsage(argv[0], EXIT_BAD_ARGS);
 
     edInitOptions(&g_ops);
     start = edParseOptions(&g_ops, argc, argv);
